@@ -1,9 +1,11 @@
 package Dist::Zilla::Plugin::GitHub;
 {
-  $Dist::Zilla::Plugin::GitHub::VERSION = '0.17';
+  $Dist::Zilla::Plugin::GitHub::VERSION = '0.18';
 }
 
+use JSON;
 use Moose;
+use Try::Tiny;
 use HTTP::Tiny;
 
 use strict;
@@ -17,7 +19,7 @@ has 'repo' => (
 has 'api'  => (
 	is      => 'ro',
 	isa     => 'Str',
-	default => 'https://github.com/api/v2/json'
+	default => 'https://api.github.com'
 );
 
 =head1 NAME
@@ -26,7 +28,7 @@ Dist::Zilla::Plugin::GitHub - Set of plugins for working with GitHub
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -63,7 +65,8 @@ sub _get_credentials {
 		$pass  = `git config github.password`; chomp $pass;
 
 		if ($token) {
-			$self -> log("Warn: Login with GitHub token is deprecated");
+			$self -> log("Err: Login with GitHub token is deprecated");
+			return (undef, undef);
 		} elsif (!$pass) {
 			require Term::ReadKey;
 
@@ -78,7 +81,26 @@ sub _get_credentials {
 		}
 	}
 
-	return ($login, $pass, $token);
+	return ($login, $pass);
+}
+
+sub _check_response {
+	my ($self, $response) = @_;
+
+	try {
+		my $json_text = from_json $response -> {'content'};
+
+		if (!$response -> {'success'}) {
+			$self -> log("Err: ", $json_text -> {'message'});
+			return;
+		}
+
+		return $json_text;
+	} catch {
+		$self -> log("Err: Can't connect to GitHub");
+
+		return;
+	}
 }
 
 =head1 ACKNOWLEDGMENTS
